Stan Math Library: stan/math/prim/scal/meta/return_type.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
return_type.hpp File Reference
`#include <stan/math/prim/scal/meta/scalar_type.hpp>`
`#include <boost/math/tools/promotion.hpp>`

Go to the source code of this file.

## Classes
struct | stan::return_type< T1, T2, T3, T4, T5, T6 >
| Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters. More...

## Namespaces
| stan

[ Stan Home Page ] © 2011–2016, Stan Development Team.